<?php
namespace Teknisa\SM\Controller;

use Teknisa\SM\Controller\SMCrud;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DataSource\DataSet;
use Teknisa\SM\Service\Sm00004006DocumentoContratoService;
use Zeedhi\Framework\Remote\FileUploader\Server;

class Sm00004006DocumentoContratoController extends SMCrud {
    
    protected $dataSourceName = 'fct_contratodoc_widget';
    protected $serviceDocumentoContrato;
    protected $zhFileUploader;
    
    public function __construct($crudService, $environment, Sm00004006DocumentoContratoService $serviceDocumentoContrato, Server $zhFileUploader) {
        parent::__construct($crudService, $environment);
        $this->serviceDocumentoContrato = $serviceDocumentoContrato;
        $this->zhFileUploader           = $zhFileUploader;
    }
    
    public function save(Request $request, Response $response) {
        try {
            $row = $request->getDataSet()->getRows()[0];
            
            if (isset($row["DSCAMINHOARQ"]) && is_array($row["DSCAMINHOARQ"])) {
                $row["NMARQUIVO"]    = $row["DSCAMINHOARQ"][0]["name"];
                $row["VRTAMANHO"]    = round($row["DSCAMINHOARQ"][0]["size"] / 1024, 2);
                $row["DSTIPO"]       = $row["DSCAMINHOARQ"][0]["type"];
                $row["DSCAMINHOARQ"] = $row["DSCAMINHOARQ"][0]["path"];
            }
            
            parent::save($request, $response);
        }
        catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function delete(Request $request, Response $response) {
        try {
            $row = $request->getRow();
            $dscaminhoarq = $row["DSCAMINHOARQ"];
            
            if (!empty($dscaminhoarq))
                $this->zhFileUploader->deleteFile($dscaminhoarq);
            
            parent::delete($request, $response);
        }
        catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    /**
     * A função "atualizaDocumento" Atualiza o documento de acordo com o modelo encontrado.
     */
    public function atualizaDocumento(Request\Row $request, Response $response) {
        try{
            $row = $request->getRow();
            
            $nrSeqContDoc   = $row["NRSEQCONTDOC"];
            $nrSeqModDocFct = $row["NRSEQMODDOCFCT"];
    
            $this->serviceDocumentoContrato->atualizaDocumento($nrSeqContDoc, $nrSeqModDocFct);
        }
        catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function excluirAnexo(Request $request, Response $response) {
        try {
            $row = $request->getRow();
            
            $nrseqcontdoc = $row["NRSEQCONTDOC"];
            $dscaminhoarq = $row["DSCAMINHOARQ"];
            $nrorg        = $row["NRORG"];
            
            $this->zhFileUploader->deleteFile($dscaminhoarq);
            
            $this->serviceDocumentoContrato->limparAnexoDoContrato($nrseqcontdoc, $nrorg);
        }
        catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    /**
     * Faz o download do documento do fileServer para a pasta tmp
    **/
    public function downloadDocFileServer(Request\Row $request, Response $response) {
        try {
            $row = $request->getRow();
            
            $nrseqcontdoc = $row["NRSEQCONTDOC"];
            $nrorg = $this->environment->getNrOrg();
        
            $result = $this->serviceDocumentoContrato->downloadDocFileServer($nrseqcontdoc, $nrorg);
            $response->addDataSet(new DataSet("URLDOCUMENTO", array($result)));
        } catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
}

?>