<?php

namespace Teknisa\SM\Service;

use Teknisa\Libs\Util\ConnectionCustom;
use Doctrine\ORM\EntityManager;
use Teknisa\SM\Factory\IntegracaoHcmfactory;
use Teknisa\Libs\Util\NewCode;
use Teknisa\Libs\Util\Environment;
use Teknisa\SM\Service\IntegracoesTeknisaService;


class IntegracaoHcmService {
    
    protected $integracaoHcmfactory;
    protected $newCode;
    protected $connectionCustom;
    protected $environment;
    protected $connection;
    protected $entityManager;
    protected $integracoesTeknisaService;
    
    public function __construct(ConnectionCustom $connectionCustom, Environment $environment, EntityManager $entityManager, IntegracoesTeknisaService $integracoesTeknisaService){
        $this->connectionCustom = $connectionCustom;
        $this->environment = $environment;
        $this->entityManager = $entityManager;
        $this->integracoesTeknisaService = $integracoesTeknisaService;
    }
    
    /**
     * Efetua as configurações necessárias para o usuário do CRM
     * salvar a proposta
     * @params array $rows dados da proposta recebidos do CRM
    **/
    public function integracaoHcm($rows){
        try{
            $nrorg = $rows["requisitante"]["nrorg"];
            $entityManagerConnection = $this->connectionCustom->updateVpdConnection($nrorg);
            
            if ($entityManagerConnection !== false) {
                $this->entityManager = $entityManagerConnection;
            }
            
            $this->connection = $this->entityManager->getConnection();
            $this->newCode = new NewCode($this->connection, "NOVO_CODIGO_SC");
            $this->integracaoHcmfactory = new IntegracaoHcmfactory($this->entityManager);
            
            $retorno = $this->buscaLancamentosDeCalculo($rows, $nrorg);
            
            return $retorno;
        } catch(\Exception $e) {
            throw $e;
        }
    }
    
    /**
     * Salva a proposta com os dados recebidos do crm
     * @params array $rows dados da proposta recebidos do CRM
    **/
    public function buscaLancamentosDeCalculo($rows, $nrorg){
        try{
            $this->connection->beginTransaction();
            
            $dtmescompetenc = $rows[""]["DTMESCOMPETENC"];
            $nrtipomoviment = $rows[""]["NRTIPOMOVIMENT"];
            $nrcpfpessoa = $rows[""]["NRCPFPESSOA"];
            
            $informacoesHoraExtra = $this->retornaLancamentosDeCalculo($nrorg, $dtmescompetenc, $nrtipomoviment, $nrcpfpessoa);

            $this->connection->commit();
            return $informacoesHoraExtra;
            
        } catch(\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }    
    }
    
    /**
     * Retorna os dados da proposta presentes no modelo
     * @params $nrorg nr organização
     * @params $nrSeqOrcamentoModelo nr do modelo
    **/
    public function retornaLancamentosDeCalculo($nrorg, $dtmescompetenc, $nrtipomoviment, $nrcpfpessoa){
        $paramsHoraExtra = array(
            "DTMESCOMPETENC" => $dtmescompetenc,
            "NRTIPOMOVIMENT" => $nrtipomoviment,
            "NRCPFPESSOA" => $nrcpfpessoa,
            "NRORG"             => $nrorg
        );
        
        $dataSet = $this->integracaoHcmfactory->retornaLancamentosDeCalculo($paramsHoraExtra);
        return $dataSet;
    }
   
   
}
